#
# spec file for package redland
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with perl

Name:           redland
%define lname	librdf0
Version:        1.0.17
Release:        4.1
Summary:        Libraries that provide support for the Resource Description Framework (RDF)
License:        Apache-2.0 AND LGPL-2.1-or-later
Group:          System/Libraries
URL:            http://www.librdf.org

Source0:        http://download.librdf.org/source/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
%if 0%{?suse_version} >= 1210
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch1:         redland-ocloexec.patch
%endif
Patch2:         redland-db6.diff
Patch3:         redland-postgresql.patch
Patch4:         redland-fix-tests.patch
BuildRequires:  autoconf
BuildRequires:  db-devel
BuildRequires:  librasqal-devel
BuildRequires:  pkg-config
BuildRequires:  postgresql-devel
BuildRequires:  sqlite-devel

%description
Redland is a library that provides a high-level interface for RDF
(Resource Description Framework) implemented in an object-based API. It
is modular and supports different RDF parsers, serializers, storage and
query languages.  Redland is designed for developers to provide RDF
support in their applications as well as a core library for RDF
developers to start with.

%package -n libredland-devel
Summary:        Development package for programs that use Redland
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description -n libredland-devel
Files needed to develop with the Redland RDF library.

%package -n %lname
Summary:        Libraries that provide support for the Resource Description Framework (RDF)
Group:          System/Libraries
%requires_ge    librasqal1
# Added for 13.1 time
Obsoletes:      libredland0 < %version-%release
Provides:       libredland0 = %version-%release

%description -n %lname
Redland is a library that provides a high-level interface for RDF
(Resource Description Framework) implemented in an object-based API. It
is modular and supports different RDF parsers, serializers, storage and
query languages.  Redland is designed for developers to provide RDF
support in their applications as well as a core library for RDF
developers to start with.

%package -n redland-storage-postgresql
Summary:        Redland storage module for PostgresSQL
Group:          System/Libraries
Requires:       redland

%description -n redland-storage-postgresql
This store provides storage using the PostgreSQL open source database
including contexts.

%prep

%setup -q
%if 0%{?suse_version} >= 1210
%patch -P 1 -p1
%endif
%patch -P 3
#
# If multiple libdb-X.Y.so are installed, redland's logic in configure.ac picks
# the library by the numbers it knows (and it may not know future versions!),
# but will use any available headers. This can lead to it choosing some random
# libdb-X.Y.so that does not match up with the headers, for linking.
#
%patch -P 2 -p1
%patch -P 4 -p1

%build
autoconf
# only compile bdb backend as it seems to be the recommended one?
%configure --enable-release --with-raptor=system --with-rasqal=system \
  --with-threestore=no --with-sqlite=3 \
  --with-postgresql --with-virtuoso=no \
  --without-mysql \
  --with-pic \
  --disable-static \
  --with-html-dir=%{_docdir}/%{name}-devel/ \
  --includedir=%{_includedir}/%{name}
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot" docdir=%{_docdir}/%{name}-devel/
rm -f %{buildroot}%{_libdir}/librdf*.la
rm -f %{buildroot}%{_libdir}/redland/librdf_storage_postgresql.la

%check
%if 0%{?suse_version} > 1030
export MALLOC_CHECK_=2
make check
unset MALLOC_CHECK_
%endif

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-, root, root)
%{_libdir}/librdf.so.*

%files -n libredland-devel
%defattr(-, root, root)
%{_bindir}/redland-config
%{_libdir}/librdf.so
%{_libdir}/pkgconfig/redland.pc
%dir %{_libdir}/redland
%{_libdir}/redland/librdf_storage_sqlite.la
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/Redland.i
%{_includedir}/%{name}/
%{_mandir}/man1/redland-config.1*
%{_mandir}/man3/redland.3*
%doc %{_docdir}/%{name}-devel/

%files -n redland-storage-postgresql
%defattr(-, root, root)
%{_libdir}/redland/librdf_storage_postgresql.so

%files
%defattr(-, root, root)
%{_bindir}/rdfproc
%{_bindir}/redland-db-upgrade
%{_libdir}/redland/librdf_storage_sqlite.so
%{_mandir}/man1/redland-db-upgrade.1*
%{_mandir}/man1/rdfproc.1*
%license COPYING COPYING.LIB LICENSE.txt LICENSE-2.0.txt
%doc AUTHORS ChangeLog NEWS README NOTICE

%changelog
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Aug 18 2023 David Anes <david.anes@suse.com>
- Fix tests against latest raptor by cleaning up parser in each iteration.
  * Added patch redland-fix-tests.patch
* Fri Mar  1 2019 Reinhard Max <max@suse.com>
- PostrgeSQL's pg_config is meant for linking server extensions,
  use libpq's pkg-config instead (redland-postgresql.patch).
  This is needed to fix build with PostgreSQL 11.
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 1.17
  * Configuration and build improvements
  * Fixed Issues: [1]0000529, [2]0000540, [3]0000541, [4]0000542 and
    [5]0000543
- Adapt redland-ocloexec.patch to upstream changes
* Sat Jun 15 2013 jengelh@inai.de
- Add redland-db6.diff to make it look for libdb 6.0
- Implement shlib packaging guidelines
  (rename libredland0 -> librdf0)
* Wed Jan  2 2013 hrvoje.senjan@gmail.com
- Update to 1.0.16
  * Fixed Issues: [1]#0000443, [2]#0000460, [3]#0000497, [4]#0000518,
    [5]#0000519
  * Postgres, MySQL and Hashes storage bug fixes.
  * Multiple other API bug fixes
  * Multiple build fixes to help building on Windows.
  * Requires Raptor 2.0.7 or newer
  * librdf_model_contains_statement() and librdf_storage_contains_
    statement() now return 0 for invalid statements
* Wed May  9 2012 darin@darins.net
- removed unnecessary postgresl-devel package and it's .la
- removed libpq5 require
* Tue May  8 2012 darin@darins.net
- Updated to include postgresql storage support and development
  packages
* Wed Dec 21 2011 tittiatcoke@gmail.com
- Update to 1.0.15
  Issues Fixed:
    0000461: librdf error - query language vsparql already
    registered
    0000468: xlc on AIX configure tests for both
    HAVE_BDB_OPEN_7_ARGS and HAVE_BDB_OPEN_6_ARGS pass
    0000475: Freeing a counted_string returned by redland on a
    modern Windows system crashes
    0000478: Object returned from librdf_stream_get_object must
    be copied, but may not copiable
    0000483: Documentation of
    librdf_parser_get_namespaces_seen_count return is
    incorrect
    0000485: No rule to make target `-lltdl', needed by
    `librdf.la'. Stop.
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Wed Nov 16 2011 tittiatcoke@gmail.com
- Ensure that the patch regarding O_CLOEXEC is only applied on
  versions equal or higher than 12.1
* Mon Nov 14 2011 crrodriguez@opensuse.org
- open all file descriptors with O_CLOEXEC to avoid
  races and leaks.
* Mon Sep 19 2011 tittiatcoke@gmail.com
- update to 1.0.14
  * Fixed Issues: [1]#0000419, [2]#0000404, [3]#0000325, [4]#0000447,
    [5]#0000432, [6]#0000418 and [7]#0000375
  * librdf_node_write() is defined to now always write N-Triples
    format
  * Added librdf_query_language_get_description() to return the full
    description of of the query language
  * Removed Raptor V1 support code as librdf no longer supports
    Raptor V1
- Created a separate package for the redland-bindings as this no
  longer compiles without redland installed
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
* Tue Feb 15 2011 davejplater@gmail.com
- Removed incomplete patch redland-perl-vendor_perl.patch until the
  fix is ready.
* Sun Jan 30 2011 davejplater@gmail.com
- Perl bindings install in site_arch disabled with bcond
* Sun Jan 16 2011 davejplater@gmail.com
- Added perl, python, php5 and ruby bindings.
* Tue Oct 19 2010 dmueller@suse.de
- update to 1.0.12:
  Enable librdf.h to be used as the top-level header in addition to
  redland.h
  Fix linking issues when building with GNU ld with DT_NEEDED disabled
  Fixed Issues: [1]#0000329, [2]#0000348 [3]#0000391, [4]#0000392 and
  [5]#0000393.
  Virtuoso storage backend querying now fully works.
  Several new convenience APIs were added and others deprecated.
  Support building with Raptor V2 API if configured with --with-raptor2.
  Exports more functions to SWIG language bindings.
  Switched to GIT version control [7]hosted by GitHub.
  Many other bug fixes and improvements were made.
  Fixed Issues: [8]#0000124, [9]#0000284, [10]#0000321, [11]#0000322,
  [12]#0000334, [13]#0000338, [14]#0000341, [15]#0000344, [16]#0000350,
  [17]#0000363, [18]#0000366, [19]#0000371, [20]#0000380, [21]#0000382
  and [22]#0000383
* Sat Jan  2 2010 dmueller@suse.de
- update to 1.0.10:
  Added a Virtuoso storage by Patrick van Kleef
  Support Rasqal 0.9.17 API
  Fix compiling against sqlite 3.6.17 or newer
  Fix modular storage dynamic loading linking problems
* Wed Dec 16 2009 dmueller@suse.de
- fix build
* Mon Jul 27 2009 beineri@opensuse.org
- update to version 1.0.9: many bug fixes
* Tue Jan 13 2009 coolo@suse.de
- fix the syntax of enums
* Thu Jul 24 2008 dmueller@suse.de
- update to 1.0.8
  * add in memory index trees
  * fix mysql connect hang
* Mon Apr  7 2008 dmueller@suse.de
- disable testsuite for older distributions
- build parallel again
* Sun Apr  6 2008 crrodriguez@suse.de
- update to version 1.0.7
  * 0000187: "rdf_query_results.c", line 630: void function cannot return value
  * 0000189: librdf_uri_is_file_uri: wrong return value
  * 0000203: API declarations for Symbian portability
  * 0000205: Memory leak in rdf_query_rasqal.c
  * 0000209: Null dereference + assertion failures in minimal librdf setup-cleanup
  * 0000213: Multiple instances of world object make trouble
  * 0000215: librdf_new_node_from_typed_counted_literal() does not respect parameter lengths
  * 0000218: librdf_query_execute does not assert model parameter
  * 0000229: Segmentation fault when invoking librdf_new_model_from_model()
  * 0000230: on Gentoo/FreeBSD redland fails compilation due to a missing #define pthread.h
  * 0000234: autogen.sh $dir quoting
  * 0000235: $(EXEEXT) in tests
  * 0000236: EOL issues when building svn version on cygwin
- disable static libraries
- remove "la" file
- cleanup -devel package dependencies again
* Thu Feb 28 2008 dmueller@suse.de
- add missing post/postun ldconfig calls
* Fri Feb 15 2008 dmueller@suse.de
- reduce -devel requires
* Tue Jan 15 2008 dmueller@suse.de
- build without postgres/mysql support for now, sqlite and bdb is
  enough. Please report if the backend support is required
* Wed May  9 2007 wstephenson@suse.de
- update to version 1.0.6
  * Added a new transactions API for graph changes, implemented for
    MySQL
  * Added a new query results formatter class
  * Many other bug fixes addressing Issues #0000175, #0000173,
    [#0000159], #0000153, #0000150 and #0000038
* Fri May  4 2007 dmueller@suse.de
- fix requires
* Thu May  3 2007 wstephenson@suse.de
- rename -devel subpackage
* Wed May  2 2007 wstephenson@suse.de
- update to version 1.0.5
  * Several API additions
  * Parsing methods can take a NULL base URI when it is not needed
  * Added serializer methods to serialize from a stream
  * Many fixes and improvements to the SQLite storage
  * Export some more functions to the SWIG binding
  * Many minor improvements
  * Many other bug fixes addressing Issues #0000092, #0000103,
    [#0000105], #0000107, #0000114, #0000116, #0000125, #0000130,
    [#0000132], #0000136 and #0000139.
* Thu Jul 13 2006 mrueckert@suse.de
- specfile cleanup
* Mon Jun 26 2006 dmacvicar@suse.de
- initial package of 1.0.4
